@@ -9,9 +9,8 @@ import os
 # Refer: https://github.com/aio-libs/aiohttp/issues/4324
 
 if platform.system() == 'Windows':
-    from asyncio.proactor_events import _ProactorBasePipeTransport
-    from pyot.utils.internal import silence_event_loop_closed
-    _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(_ProactorBasePipeTransport.__del__)
+    from pyot.utils.internal import silence_proactor_pipe_deallocation
+    silence_proactor_pipe_deallocation()
 
 
 # Pyot documentations for settings
