@@ -1,7 +1,7 @@
-from .__core__ import PyotCore, PyotStatic
-from datetime import datetime, timedelta
+from datetime import datetime
 from typing import List, Iterator
 from dateutil.parser import parse
+from .__core__ import PyotCore, PyotStatic
 
 ## PYOT STATIC OBJECTS
 
@@ -46,18 +46,18 @@ class MatchPlayerData(PyotStatic):
 class MatchInfoData(PyotStatic):
     mode: str # (Legal values: Constructed, Expeditions, Tutorial)
     type: str # (Legal values: Ranked, Normal, AI, Tutorial, VanillaTrial, Singleton, StandardGauntlet)
+    start_strftime: str
     creation: datetime
     version: str
     players: List[MatchPlayerData]
     total_turn_count: int
 
     class Meta(PyotStatic.Meta):
-        renamed = {"game_mode": "mode", "game_type": "type", "game_start_time_utc": "creation", "game_version": "version"}
+        renamed = {"game_mode": "mode", "game_type": "type", "game_start_time_utc": "start_strftime", "game_version": "version"}
 
-    def __getattribute__(self, name):
-        if name == "creation":
-            return parse(super().__getattribute__(name))
-        return super().__getattribute__(name)
+    @property
+    def creation(self):
+        return parse(self.start_strftime)
 
 
 ## PYOT CORE OBJECTS
