@@ -1,5 +1,5 @@
-from .__core__ import PyotCore
 from datetime import datetime
+from .__core__ import PyotCore
 
 
 # PYOT CORE OBJECTS
@@ -11,6 +11,7 @@ class Summoner(PyotCore):
     level: int
     puuid: str
     profile_icon_id: int
+    revision_date_millis: int
     revision_date: datetime
 
     class Meta(PyotCore.Meta):
@@ -20,16 +21,15 @@ class Summoner(PyotCore):
             "summoner_v1_by_puuid": ["puuid"],
             "summoner_v1_by_name": ["name"],
         }
-        renamed = {"summoner_level": "level"}
-
-    def __getattribute__(self, name):
-        if name == "revision_date":
-            return datetime.fromtimestamp(super().__getattribute__(name)//1000)
-        return super().__getattribute__(name)
+        renamed = {"summoner_level": "level", "revision_date": "revision_date_millis"}
 
     def __init__(self, id: str = None, account_id: str = None, name: str = None, puuid: str = None, platform: str = None):
         self._lazy_set(locals())
 
+    @property
+    def revision_date(self) -> datetime:
+        return datetime.fromtimestamp(self.revision_date_millis//1000)
+
     @property
     def league_entries(self) -> "SummonerLeague":
         from .league import SummonerLeague
@@ -53,4 +53,4 @@ class Summoner(PyotCore):
     @property
     def match_history(self) -> "MatchHistory":
         from .match import MatchHistory
-        return MatchHistory(puuid=self.puuid, region=self.to_region(self.platform))
\ No newline at end of file
+        return MatchHistory(puuid=self.puuid, region=self.to_region(self.platform))
